@@ -16,24 +16,18 @@
 """Service action implementations"""
 
 import argparse
-import logging
 import six
 
-from cliff import command
-from cliff import lister
-from cliff import show
-
+from openstackclient.common import command
 from openstackclient.common import exceptions
 from openstackclient.common import utils
 from openstackclient.i18n import _  # noqa
 from openstackclient.identity import common
 
 
-class CreateService(show.ShowOne):
+class CreateService(command.ShowOne):
     """Create new service"""
 
-    log = logging.getLogger(__name__ + '.CreateService')
-
     def get_parser(self, prog_name):
         parser = super(CreateService, self).get_parser(prog_name)
         parser.add_argument(
@@ -60,7 +54,6 @@ class CreateService(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
 
         type_or_name = parsed_args.type_or_name
@@ -95,8 +88,6 @@ class CreateService(show.ShowOne):
 class DeleteService(command.Command):
     """Delete service"""
 
-    log = logging.getLogger(__name__ + '.DeleteService')
-
     def get_parser(self, prog_name):
         parser = super(DeleteService, self).get_parser(prog_name)
         parser.add_argument(
@@ -107,18 +98,14 @@ class DeleteService(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
         service = common.find_service(identity_client, parsed_args.service)
         identity_client.services.delete(service.id)
-        return
 
 
-class ListService(lister.Lister):
+class ListService(command.Lister):
     """List services"""
 
-    log = logging.getLogger(__name__ + '.ListService')
-
     def get_parser(self, prog_name):
         parser = super(ListService, self).get_parser(prog_name)
         parser.add_argument(
@@ -130,7 +117,6 @@ class ListService(lister.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
 
         if parsed_args.long:
             columns = ('ID', 'Name', 'Type', 'Description')
@@ -143,11 +129,9 @@ class ListService(lister.Lister):
         )
 
 
-class ShowService(show.ShowOne):
+class ShowService(command.ShowOne):
     """Display service details"""
 
-    log = logging.getLogger(__name__ + '.ShowService')
-
     def get_parser(self, prog_name):
         parser = super(ShowService, self).get_parser(prog_name)
         parser.add_argument(
@@ -164,7 +148,6 @@ class ShowService(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
         auth_ref = self.app.client_manager.auth_ref
 
